=== modified file '.bzrignore'
--- .bzrignore	2007-01-14 05:43:15 +0000
+++ .bzrignore	2008-07-29 20:42:35 +0000
@@ -3,3 +3,4 @@
 ./loggerhead.conf
 ./loggerhead.pid
 ./logs
+build

=== removed file '.project'
--- .project	2006-12-11 06:44:19 +0000
+++ .project	1970-01-01 00:00:00 +0000
@@ -1,17 +0,0 @@
-<?xml version="1.0" encoding="UTF-8"?>
-<projectDescription>
-	<name>loggerhead</name>
-	<comment></comment>
-	<projects>
-	</projects>
-	<buildSpec>
-		<buildCommand>
-			<name>org.python.pydev.PyDevBuilder</name>
-			<arguments>
-			</arguments>
-		</buildCommand>
-	</buildSpec>
-	<natures>
-		<nature>org.python.pydev.pythonNature</nature>
-	</natures>
-</projectDescription>

=== modified file 'NEWS'
--- NEWS	2008-07-26 17:59:26 +0000
+++ NEWS	2008-07-31 05:41:42 +0000
@@ -4,8 +4,12 @@
 1.6 [unreleased]
 ----------------
 
+    - Default sqlite interface is now sqlite3. (Robert Collins)
+
     - New ninja theme sponsored by Canonical (Martin Albisetti)
 
+    - Added COPYING file and clarified copyright headers (John Arbash Meinel)
+
     - Remove the .py extension requiered by the Debian Policy.
       (Jelmer Vernooij)
 
@@ -57,7 +61,6 @@
       cache.
 
 1.2  [04mar2008]
-----------------
 
     - Michael Hudson <michael.hudson@canonical.com> has mostly taken
       over the maintenance of loggerhead.

=== modified file 'loggerhead/__init__.py'
--- loggerhead/__init__.py	2008-07-26 14:52:44 +0000
+++ loggerhead/__init__.py	2008-07-29 22:00:33 +0000
@@ -13,3 +13,5 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 """Just a simple container to turn this into a python package."""
+__version__ = '1.6'
+required_bzrlib = (1, 6)

=== modified file 'loggerhead/apps/branch.py'
--- loggerhead/apps/branch.py	2008-07-09 08:39:59 +0000
+++ loggerhead/apps/branch.py	2008-08-05 05:17:47 +0000
@@ -23,10 +23,12 @@
 
 class BranchWSGIApp(object):
 
-    def __init__(self, branch, friendly_name=None, config={}, graph_cache=None):
+    def __init__(self, branch, friendly_name=None, config={},
+                 graph_cache=None, branch_link=None):
         self.branch = branch
         self._config = config
         self.friendly_name = friendly_name
+        self.branch_link = branch_link  # Currently only used in Launchpad
         self.log = logging.getLogger('loggerhead.%s' % (friendly_name,))
         if graph_cache is None:
             graph_cache = bzrlib.lru_cache.LRUCache()

=== modified file 'loggerhead/apps/filesystem.py'
--- loggerhead/apps/filesystem.py	2008-07-01 04:01:31 +0000
+++ loggerhead/apps/filesystem.py	2008-08-05 05:11:33 +0000
@@ -1,50 +1,31 @@
 """Serve branches at urls that mimic the file system layout."""
 
-import cgi
 import os
 import tempfile
 
 from bzrlib import branch, errors, lru_cache
 
 from paste.request import path_info_pop
-from paste.wsgiwrappers import WSGIRequest, WSGIResponse
 from paste import httpexceptions
 
 from loggerhead.apps.branch import BranchWSGIApp
 from loggerhead.apps import favicon_app, static_app
-
-sql_dir = tempfile.mkdtemp()
-
-
-class DirectoryListing(object):
-
-    def __init__(self, path):
+from loggerhead.controllers.directory_ui import DirectoryUI
+
+sql_dir = tempfile.mkdtemp(prefix='loggerhead-cache-')
+
+
+class BranchesFromFileSystemServer(object):
+    def __init__(self, path, root, name=None):
         self.path = path
-
-    def __call__(self, environ, start_response):
-        request = WSGIRequest(environ)
-        response = WSGIResponse()
-        listing = [d for d in os.listdir(self.path) if not d.startswith('.')]
-        response.headers['Content-Type'] = 'text/html'
-        print >> response, '<html><body>'
-        for d in sorted(listing):
-            if os.path.isdir(os.path.join(self.path, d)):
-                d = cgi.escape(d)
-                print >> response, '<li><a href="%s/">%s</a></li>' % (d, d)
-        print >> response, '</body></html>'
-        return response(environ, start_response)
-
-
-class BranchesFromFileSystemServer(object):
-    def __init__(self, folder, root):
-        self.folder = folder
         self.root = root
+        self.name = name
 
     def app_for_branch(self, branch):
-        if not self.folder:
-            name = os.path.basename(os.path.abspath(self.root.folder))
+        if not self.name:
+            name = branch.nick
         else:
-            name = self.folder
+            name = self.name
         branch_app = BranchWSGIApp(
             branch, name, {'cachepath': sql_dir}, self.root.graph_cache)
         return branch_app.app
@@ -55,17 +36,24 @@
             raise httpexceptions.HTTPMovedPermanently(
                 environ['SCRIPT_NAME'] + '/')
         elif segment == '':
-            return DirectoryListing(os.path.join(self.root.folder, self.folder))
+            if self.name:
+                name = self.name
+            else:
+                name = '/'
+            return DirectoryUI(environ['loggerhead.static.url'], self.path, name)
         else:
-            relpath = os.path.join(self.folder, segment)
-            return BranchesFromFileSystemServer(relpath, self.root)
+            new_path = os.path.join(self.path, segment)
+            if self.name:
+                new_name = os.path.join(self.name, segment)
+            else:
+                new_name = '/' + segment
+            return BranchesFromFileSystemServer(new_path, self.root, new_name)
 
     def __call__(self, environ, start_response):
-        path = os.path.join(self.root.folder, self.folder)
-        if not os.path.isdir(path):
+        if not os.path.isdir(self.path):
             raise httpexceptions.HTTPNotFound()
         try:
-            b = branch.Branch.open(path)
+            b = branch.Branch.open(self.path)
         except errors.NotBranchError:
             return self.app_for_non_branch(environ)(environ, start_response)
         else:
@@ -88,4 +76,33 @@
             return favicon_app(environ, start_response)
         else:
             return BranchesFromFileSystemServer(
-                '', self)(environ, start_response)
+                self.folder, self)(environ, start_response)
+
+
+class UserBranchesFromFileSystemRoot(object):
+
+    def __init__(self, folder, trunk_dir):
+        self.graph_cache = lru_cache.LRUCache()
+        self.folder = folder
+        self.trunk_dir = trunk_dir
+
+    def __call__(self, environ, start_response):
+        environ['loggerhead.static.url'] = environ['SCRIPT_NAME']
+        path_info= environ['PATH_INFO']
+        if path_info.startswith('/static/'):
+            segment = path_info_pop(environ)
+            assert segment == 'static'
+            return static_app(environ, start_response)
+        elif path_info == '/favicon.ico':
+            return favicon_app(environ, start_response)
+        else:
+            # segments starting with ~ are user branches
+            if path_info.startswith('/~'):
+                segment = path_info_pop(environ)
+                new_path = os.path.join(self.folder, segment[1:])
+                return BranchesFromFileSystemServer(
+                    new_path, self, segment)(environ, start_response)
+            else:
+                new_path = os.path.join(self.folder, self.trunk_dir)
+                return BranchesFromFileSystemServer(
+                    new_path, self)(environ, start_response)

=== modified file 'loggerhead/changecache.py'
--- loggerhead/changecache.py	2008-07-22 00:40:03 +0000
+++ loggerhead/changecache.py	2008-07-31 05:41:42 +0000
@@ -33,15 +33,11 @@
 
 with_lock = util.with_lock('_lock', 'ChangeCache')
 
-SQLITE_INTERFACE = os.environ.get('SQLITE_INTERFACE', 'sqlite')
+SQLITE_INTERFACE = os.environ.get('SQLITE_INTERFACE', 'sqlite3')
 
-if SQLITE_INTERFACE == 'pysqlite2':
-    from pysqlite2 import dbapi2
+if SQLITE_INTERFACE == 'sqlite3':
+    from sqlite3 import dbapi2
     _param_marker = '?'
-elif SQLITE_INTERFACE == 'sqlite':
-    import sqlite as dbapi2
-    _param_marker = '%s'
-
 
 _select_stmt = ("select data from revisiondata where revid = ?"
                 ).replace('?', _param_marker)

=== added file 'loggerhead/controllers/directory_ui.py'
--- loggerhead/controllers/directory_ui.py	1970-01-01 00:00:00 +0000
+++ loggerhead/controllers/directory_ui.py	2008-08-04 21:22:16 +0000
@@ -0,0 +1,73 @@
+# Copyright (C) 2008  Canonical Ltd.
+#                     (Authored by Martin Albisetti <argentina@gmail.com>)
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#
+
+import datetime
+import logging
+import os
+
+from bzrlib import branch
+
+from loggerhead.controllers import TemplatedBranchView
+
+class DirEntry(object):
+    def __init__(self, dirname, parity, branch):
+        self.dirname = dirname
+        self.parity = parity
+        self.branch = branch
+        if branch is not None:
+            self.last_change =  datetime.datetime.fromtimestamp(
+                branch.repository.get_revision(branch.last_revision()).timestamp)
+
+class DirectoryUI(TemplatedBranchView):
+    """
+    """
+
+    template_path = 'loggerhead.templates.directory'
+
+    def __init__(self, static_url_base, path, name):
+        class _branch(object):
+            context_url = 1
+        self._branch = _branch
+        self._history = None
+        self._path = path
+        self._name = name
+        self._static_url_base = static_url_base
+        self.log = logging.getLogger('')
+
+    def get_values(self, h, args, kwargs, response):
+        listing = [d for d in os.listdir(self._path)
+                   if not d.startswith('.')
+                   and os.path.isdir(os.path.join(self._path, d))]
+        listing.sort(key=lambda x: x.lower())
+        dirs = []
+        parity = 0
+        def static_url(path):
+            return self._static_url_base + path
+        for d in listing:
+            p = os.path.join(self._path, d)
+            try:
+                b = branch.Branch.open(p)
+            except:
+                b = None
+            dirs.append(DirEntry(d, parity, b))
+            parity = 1 - parity
+        return {
+            'dirs': dirs,
+            'name': self._name,
+            'static_url': static_url,
+            }

=== removed file 'loggerhead/release.py'
--- loggerhead/release.py	2008-03-06 01:59:26 +0000
+++ loggerhead/release.py	1970-01-01 00:00:00 +0000
@@ -1,12 +0,0 @@
-# Release information about loggerhead
-
-version = "1.2.1"
-
-description = "Loggerhead is a web viewer for projects in bazaar."
-
-author = "Robey Pointer"
-email = "robey@lag.net"
-
-license = "GPL"
-url = "http://launchpad.net/loggerhead"
-download_url = "https://launchpad.net/loggerhead/trunk/1.2/+download/loggerhead-1.2.tar.gz"

=== modified file 'loggerhead/static/css/global.css'
--- loggerhead/static/css/global.css	2008-07-24 02:40:21 +0000
+++ loggerhead/static/css/global.css	2008-08-05 06:17:12 +0000
@@ -18,11 +18,11 @@
 	outline:none;
 }
 form {
-	margin:0;
-	padding:0;
+  margin: 0;
+  padding: 0;
 }
 tr td {
-    vertical-align:top
+  vertical-align: top;
 }
 .clear {
 	clear:both;
@@ -93,27 +93,27 @@
 	text-align:center;
 	color:#fff;
 	text-decoration:none;
-	background:#d18b39;
+	background:#2f40a5;
 }
 ul#submenuTabs li {
 	float:left;
 	display:inline;
 	margin-left:1px;
 	color:#fff;
-	background:#d18b39;
+	background:#2f40a5;
 }
 ul#submenuTabs li a:hover {
 	float:left;
 	display:inline;
 	color:#fff;
-	background:#d18b39;
+	background:#2f40a5;
 	text-decoration:underline;
 }
 ul#submenuTabs li#first a, ul#submenuTabs li#first a:link, ul#submenuTabs li#first a:visited, ul#submenuTabs li#first a:hover {
-	background:#d18b39 url(../images/bg_submenuTabs.gif) top left no-repeat;
+	background:#2f40a5 url(../images/bg_submenuTabs.gif) top left no-repeat;
 }
 ul#submenuTabs li#last a, ul#submenuTabs li#last a:link, ul#submenuTabs li#last a:visited, ul#submenuTabs li#last a:hover {
-	background:#d18b39 url(../images/bg_submenuTabs.gif) bottom right no-repeat;
+	background:#2f40a5 url(../images/bg_submenuTabs.gif) bottom right no-repeat;
 }
 
 /* Search & RSS */
@@ -186,7 +186,6 @@
 	padding:0px 11px 0px 0px;
 	margin:0px 2px 0px 0px;
 	font-weight:bold;
-	background:url(../images/ico_link.gif) right top no-repeat;
 }
 .revnolink a, .revnolink a:visited, .revnolink a:link, .revnolink a:hover {
 	color:#CC6600;
@@ -228,15 +227,15 @@
 .expandcell, .expcell {
 	width:28px;	
 }
-.summarycell, .authorcell, .datecell, .summcell, .autcell, .date, .timedate, .timedate2 {
-	padding:4px 8px;
-	border:1px solid #d2d2d2;
+.summarycell, .authorcell, .datecell, .timedate{
+  padding: 4px 8px;
+  border: 1px solid #d2d2d2;
 }
-.authorcell, .autcell {
-	width:202px;
+.icocell {
+  width: 18px;
 }
 .datecell, .date {
-	width:110px;
+  width: 180px;
 }
 .timedate, .timedate2 {
 	width:80px;
@@ -244,9 +243,10 @@
 .downloadcell, .downr {
 	width:47px;
 }
-.revnro, .expcell, .diffr, .summcell, .autcell, .date, .downr, .allicones, .timedate2 {
-	border:none;
-	border-bottom:1px solid #d2d2d2;
+.revnro, .expcell, .diffr, .summcell, .autcell, .icocell, .date, .downr, .allicones, .timedate2 {
+  border: 0;
+  padding: 4px 4px;
+  border-bottom:1px solid #d2d2d2;
 }
 .revisioninfo {
     margin-top:4px;

=== modified file 'loggerhead/static/images/bg_Tabs.gif'
Binary files loggerhead/static/images/bg_Tabs.gif and loggerhead/static/images/bg_Tabs.gif differ
=== modified file 'loggerhead/static/images/bg_menuTabs.gif'
Binary files loggerhead/static/images/bg_menuTabs.gif and loggerhead/static/images/bg_menuTabs.gif differ
=== modified file 'loggerhead/static/images/bg_submenuTabs.gif'
Binary files loggerhead/static/images/bg_submenuTabs.gif and loggerhead/static/images/bg_submenuTabs.gif differ
=== added file 'loggerhead/static/images/ico_branch.gif'
Binary files loggerhead/static/images/ico_branch.gif and loggerhead/static/images/ico_branch.gif differ
=== added file 'loggerhead/static/images/ico_folder_up.gif'
Binary files loggerhead/static/images/ico_folder_up.gif and loggerhead/static/images/ico_folder_up.gif differ
=== modified file 'loggerhead/templates/annotate.pt'
--- loggerhead/templates/annotate.pt	2008-07-23 23:00:16 +0000
+++ loggerhead/templates/annotate.pt	2008-08-04 03:42:01 +0000
@@ -15,8 +15,16 @@
   <body>
 
     <h1 metal:fill-slot="heading">
-        <tal:block content="branch/friendly_name"></tal:block>
-        <span>: <span tal:content="path"></span> (revision <tal:revno content="change/revno"></tal:revno>)</span>
+      <tal:has-link condition="branch/branch_link">
+        <a tal:attributes="href branch/branch_link"
+           tal:content="branch/friendly_name">
+          nice/branch/name
+        </a>
+      </tal:has-link>
+      <tal:no-link condition="not: branch/branch_link">
+        <tal:branch-name replace="branch/friendly_name" />
+      </tal:no-link>
+      <span>: <span tal:content="path"></span> (revision <tal:revno content="change/revno"></tal:revno>)</span>
     </h1>
 
     <div metal:fill-slot="content">

=== modified file 'loggerhead/templates/changelog.pt'
--- loggerhead/templates/changelog.pt	2008-07-24 02:40:21 +0000
+++ loggerhead/templates/changelog.pt	2008-08-04 03:42:01 +0000
@@ -14,7 +14,16 @@
     <body>
         <tal:block metal:fill-slot="heading">
          <h1>
-          <tal:block content="branch/friendly_name"></tal:block>: changes
+           <tal:has-link condition="branch/branch_link">
+             <a tal:attributes="href branch/branch_link"
+                tal:content="branch/friendly_name">
+               nice/branch/name
+             </a>
+           </tal:has-link>
+           <tal:no-link condition="not: branch/branch_link">
+             <tal:branch-name replace="branch/friendly_name" />
+           </tal:no-link>
+           : changes
           <tal:block condition="filter_file_id">to <span tal:content="python:history.get_path(revid, filter_file_id)" /></tal:block>
           <tal:block condition="start_revid">from revision <tal:block content="python:history.get_revno(start_revid)" /></tal:block>
           <tal:block condition="query">matching <tal:block content="query" /></tal:block>

=== added file 'loggerhead/templates/directory.pt'
--- loggerhead/templates/directory.pt	1970-01-01 00:00:00 +0000
+++ loggerhead/templates/directory.pt	2008-08-05 06:12:07 +0000
@@ -0,0 +1,67 @@
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
+<html xmlns="http://www.w3.org/1999/xhtml" >
+  <head>
+    <title tal:content="string:Browsing ${name}"></title>
+    <link rel="stylesheet"
+          tal:attributes="href python:static_url('/static/css/global.css')" />
+  </head>
+  <body>
+    <div id="loggerheadCont">
+      <h1 tal:content="string:Browsing ${name}">
+        Hi.
+      </h1>
+
+      <div >
+        <table id="logentries">
+          <tr class="logheader">
+            <th class="summarycell" colspan="2">Filename</th>
+            <th class="datecell">Latest Rev</th>
+            <th class="datecell">Last Changed</th>
+          </tr>
+          
+          <tr class="blueRow0" tal:condition="python:name != '/'">
+            <td class="icocell">
+                <a href=".."><img tal:attributes="src python:static_url('/static/images/ico_folder_up.gif')" /></a>
+            </td>
+            <td class="summcell" colspan="3">
+                <a href="..">..</a>
+            </td>
+          </tr>
+          <tal:block repeat="dir dirs">
+
+            <tal:branch-row tal:condition="dir/branch">
+              <tr tal:attributes="class string:blueRow${dir/parity}">
+                <td class="icocell">
+                    <a tal:attributes="href string:${dir/dirname}/files">
+                        <img tal:attributes="src python:static_url('/static/images/ico_branch.gif')" />
+                    </a>
+                </td>
+                <td class="autcell">
+                  <a tal:attributes="href string:${dir/dirname}/files" tal:content="dir/dirname" /></td>
+                <td class="date">
+                  <a tal:attributes="href string:${dir/dirname}/revision/${dir/branch/revno};
+                                     title string:Show revision ${dir/branch/revno}"
+                     tal:content="dir/branch/revno"></a>
+                </td>
+                <td class="date" tal:content="python:util.date_time(dir.last_change)"></td>
+              </tr>
+            </tal:branch-row>
+            <tal:non-branch-row tal:condition="not:dir/branch">
+              <tr tal:attributes="class string:blueRow${dir/parity}">
+                <td class="icocell">
+                    <a tal:attributes="href string:${dir/dirname}">
+                        <img tal:attributes="src python:static_url('/static/images/ico_folder.gif')" />
+                    </a>
+                </td>
+                <td class="autcell">
+                  <a tal:attributes="href string:${dir/dirname}" tal:content="dir/dirname" /></td>
+                <td class="date"></td>
+                <td class="date" tal:content="dir/last_change"></td>
+              </tr>
+            </tal:non-branch-row>
+          </tal:block>
+        </table>
+      </div>
+    </div>
+  </body>
+</html>

=== modified file 'loggerhead/templates/inventory.pt'
--- loggerhead/templates/inventory.pt	2008-07-25 02:05:12 +0000
+++ loggerhead/templates/inventory.pt	2008-08-05 06:21:09 +0000
@@ -11,8 +11,17 @@
   <body>
 
     <h1 metal:fill-slot="heading">
-        <tal:block content="branch/friendly_name" />: viewing 
-        <span><tal:block content="path" /></span> for revision <span><tal:revno content="change/revno"></tal:revno></span>
+      <tal:has-link condition="branch/branch_link">
+        <a tal:attributes="href branch/branch_link"
+           tal:content="branch/friendly_name">
+          nice/branch/name
+        </a>
+      </tal:has-link>
+      <tal:no-link condition="not: branch/branch_link">
+        <tal:branch-name replace="branch/friendly_name" />
+      </tal:no-link>
+      : viewing
+      <span tal:content="path" /> for revision <span tal:content="change/revno"/>
     </h1>
 
     <div metal:fill-slot="content">
@@ -39,7 +48,8 @@
 
           <tr class="blueRow0" tal:condition="python:updir">
               <td class="summcell" colspan="6">
-                  <a tal:attributes="href python:url(['/files', revid], file_id=updir_file_id)" class="link">..</a>
+                  <a tal:attributes="href python:url(['/files', revid], file_id=updir_file_id)" class="link">
+                      <img tal:attributes="src python:branch.static_url('/static/images/ico_folder_up.gif')" />..</a>
               </td>
           </tr>
           

=== modified file 'loggerhead/templates/macros.pt'
--- loggerhead/templates/macros.pt	2008-07-22 21:50:55 +0000
+++ loggerhead/templates/macros.pt	2008-08-04 03:42:01 +0000
@@ -32,7 +32,7 @@
             </div>
           </div>
         </form>
-        
+
         <tal:block tal:condition="not:fileview_active">
         <li><a tal:attributes="href python:url('/changes', clear=1);
                                title string:Changes;
@@ -47,17 +47,15 @@
                                title string:Files;
                                id string:on">Files</a></li>
         </tal:block>
-        <li><a tal:attributes="href string:https://help.launchpad.net/Loggerhead;
-                               title string:Help">Help</a></li>       
       </ul>
       <div id="loggerheadCont">
-    
+
          <div id="search_terms"></div>
 
         <h1 metal:define-slot="heading"></h1>
         <div metal:define-slot="content"></div>
 
-        <p class="fl">Launchpad runs <a href="https://launchpad.net/loggerhead" class="link">Loggerhead</a> on <a href="http://bazaar-vcs.org/" class="link">Bazaar</a> branches</p>
+        <p class="fl">Loggerhead runs on <a href="http://bazaar-vcs.org/" class="link">Bazaar</a> branches</p>
     </div>
   </body>
 </html>

=== modified file 'loggerhead/templates/revision.pt'
--- loggerhead/templates/revision.pt	2008-07-24 00:17:48 +0000
+++ loggerhead/templates/revision.pt	2008-08-04 03:42:01 +0000
@@ -15,7 +15,17 @@
     <body>
 
       <tal:block metal:fill-slot="heading">
-        <h1><tal:block content="branch/friendly_name" /><span>: <tal:revno content="change/revno"></tal:revno>
+        <h1>
+          <tal:has-link condition="branch/branch_link">
+            <a tal:attributes="href branch/branch_link"
+               tal:content="branch/friendly_name">
+              nice/branch/name
+            </a>
+          </tal:has-link>
+          <tal:no-link condition="not: branch/branch_link">
+            <tal:branch-name replace="branch/friendly_name" />
+          </tal:no-link>
+          <span>: <tal:revno content="change/revno"></tal:revno>
         <tal:compare-to condition="python:compare_revid is not None">
           (compared to revision <tal:block content="python:history.get_revno(compare_revid)" />)
           </tal:compare-to>

=== modified file 'serve-branches'
--- serve-branches	2008-07-26 17:41:49 +0000
+++ serve-branches	2008-08-01 04:42:14 +0000
@@ -16,36 +16,81 @@
 """Search for branches underneath a directory and serve them all."""
 
 import logging
+import os
 import sys
 
+from optparse import OptionParser
+
 from paste import httpserver
 from paste.httpexceptions import HTTPExceptionHandler
 from paste.translogger import TransLogger
 
-from loggerhead.apps.filesystem import BranchesFromFileSystemRoot
-
-
-logging.basicConfig()
-logging.getLogger().setLevel(logging.DEBUG)
-
-if len(sys.argv) > 1:
-    path = sys.argv[1]
-else:
-    path = '.'
-
-app = BranchesFromFileSystemRoot(path)
-
-app = HTTPExceptionHandler(app)
-app = TransLogger(app)
-
-try:
-    from paste.deploy.config import PrefixMiddleware
-except ImportError:
-    pass
-else:
-    app = PrefixMiddleware(app)
-
-#from paste.evalexception import EvalException
-#app = EvalException(app)
-
-httpserver.serve(app, host='0.0.0.0', port='8080')
+from loggerhead import __version__
+from loggerhead.apps.filesystem import (
+    BranchesFromFileSystemRoot, UserBranchesFromFileSystemRoot)
+
+
+def command_line_parser():
+    parser = OptionParser("%prog [options] <path>")
+    parser.set_defaults(
+        user_dirs=False,
+        show_version=False,
+        )
+    parser.add_option("--user-dirs", action="store_true", dest="user_dirs",
+                      help="Serve user directories as ~user.")
+    parser.add_option("--trunk-dir", metavar="DIR",
+                      help="The directory that contains the trunk branches.")
+    parser.add_option("--version", action="store_true", dest="show_version",
+                      help="Print the software version and exit")
+    return parser
+
+
+def main(args):
+    logging.basicConfig()
+    logging.getLogger().setLevel(logging.DEBUG)
+
+    parser = command_line_parser()
+    (options, args) = parser.parse_args(sys.argv[1:])
+
+    if options.show_version:
+        print "loggerhead %s" % __version__
+        sys.exit(0)
+
+    if len(args) > 1:
+        parser.print_help()
+        sys.exit(1)
+    elif len(args) == 1:
+        [path] = args
+    else:
+        path = '.'
+
+    if not os.path.isdir(path):
+        print "%s is not a directory" % path
+        sys.exit(1)
+
+    if options.trunk_dir and not options.user_dirs:
+        print "--trunk-dir is only valid with --user-dirs"
+        sys.exit(1)
+
+    if options.user_dirs:
+        if not options.trunk_dir:
+            print "You didn't specify a directory for the trunk directories."
+            sys.exit(1)
+        app = UserBranchesFromFileSystemRoot(path, options.trunk_dir)
+    else:
+        app = BranchesFromFileSystemRoot(path)
+    app = HTTPExceptionHandler(app)
+    app = TransLogger(app)
+
+    try:
+        from paste.deploy.config import PrefixMiddleware
+    except ImportError:
+        pass
+    else:
+        app = PrefixMiddleware(app)
+
+    httpserver.serve(app, host='0.0.0.0', port='8080')
+
+
+if __name__ == "__main__":
+    main(sys.argv)

=== added file 'serve-branches.1'
--- serve-branches.1	1970-01-01 00:00:00 +0000
+++ serve-branches.1	2008-08-05 16:02:23 +0000
@@ -0,0 +1,29 @@
+.TH LOGGERHEAD "1" "August 2008" "loggerhead 1.6" "User Commands"
+.SH NAME
+loggerhead \- manual page for loggerhead 1.6
+.SH SYNOPSIS
+.B serve-branches
+[\fIoptions\fR] \fI<path>\fR
+.SH DESCRIPTION
+Loggerhead is a web viewer for projects in bazaar. It can be used to navigate 
+a branch history, annotate files, view patches, perform searches, etc. It's 
+heavily based on bazaar-webserve, which is itself based on hgweb for Mercurial.
+.PP
+The serve-branches command runs a standalone loggerhead server in the foreground.
+.SH OPTIONS
+.TP
+\fB\-h\fR, \fB\-\-help\fR
+show this help message and exit
+.TP
+\fB\-\-user\-dirs\fR
+Serve user directories as ~user.
+.TP
+\fB\-\-trunk\-dir\fR=\fIDIR\fR
+The directory that contains the trunk branches.
+.TP
+\fB\-\-version\fR
+Print the software version and exit
+.SH "LICENSE"
+GNU GPLv2 or later.
+.SH "SEE ALSO"
+https://launchpad.net/loggerhead

=== modified file 'setup.py'
--- setup.py	2008-07-26 17:41:49 +0000
+++ setup.py	2008-08-05 16:02:23 +0000
@@ -1,4 +1,7 @@
 #!/usr/bin/env python
+#
+# Copyright (C) 2008  Canonical Ltd.
+#                     (Authored by Martin Albisetti <argentina@gmail.com>)
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
@@ -13,49 +16,32 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-from setuptools import setup, find_packages
-from turbogears.finddata import find_package_data
-
-import os
-execfile(os.path.join("loggerhead", "release.py"))
+"""Loggerhead is a web viewer for projects in bazaar"""
+
+
+from distutils.core import setup
+import loggerhead
 
 
 setup(
-    name="loggerhead",
-    version=version,
-    
-    description=description,
-    author=author,
-    author_email=email,
-    url=url,
-    download_url=download_url,
-    license=license,
-    maintainer="Michael Hudson",
-    maintainer_email="michael.hudson@canonical.com",
-    
-    install_requires = [
-        "TurboGears >= 1.0b1",
-# for some reason, distutils can't find bzr.
-#        "bzr >= 0.13",
-    ],
+    name = "loggerhead",
+    version = loggerhead.__version__,
+    description = "Loggerhead is a web viewer for projects in bazaar",
+    license = "GNU GPL v2 or later",
+    maintainer = "Michael Hudson",
+    maintainer_email = "michael.hudson@canonical.com",
     scripts = ["start-loggerhead", "stop-loggerhead", "serve-branches"],
-    zip_safe=False,
-    packages=find_packages(),
-    package_data = find_package_data(where='loggerhead',
-                                     package='loggerhead'),
-#    data_files = find_package_data(where='loggerhead', package='loggerhead'),
-    data_files=[('share/man/man1', 
-                    ['start-loggerhead.1', 'stop-loggerhead.1'])],
-    keywords = [
-        'turbogears.app',
-    ],
-    classifiers = [
-        'Development Status :: 3 - Alpha',
-        'Operating System :: OS Independent',
-        'Programming Language :: Python',
-        'Framework :: TurboGears',
-        'Framework :: TurboGears :: Applications',
-    ],
-    test_suite = 'nose.collector',
+    packages = ["loggerhead", 
+                "loggerhead/apps", 
+                "loggerhead/controllers", 
+                "loggerhead/templates"],
+    package_data = {"loggerhead":["templates/*.pt", 
+                                  "static/css/*.css", 
+                                  "static/javascript/*", 
+                                  "static/images/*"]},
+    data_files = [
+        ('share/man/man1',['start-loggerhead.1', 'stop-loggerhead.1', 
+                           'serve-branches.1']),
+        ('share/doc/loggerhead', ['loggerhead.conf.example']),
+        ],
     )
-    

=== modified file 'stop-loggerhead'
--- stop-loggerhead	2008-07-26 14:52:44 +0000
+++ stop-loggerhead	2008-08-04 23:46:37 +0000
@@ -15,9 +15,6 @@
 
 """A script for stopping the loggerhead process."""
 
-import pkg_resources
-pkg_resources.require("TurboGears")
-
 import os
 import sys
 

